@@ -6,9 +6,7 @@ import (
 	orgv2 "github.com/confluentinc/ccloud-sdk-go-v2/org/v2"
 
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
-	"github.com/confluentinc/cli/internal/pkg/errors"
 	"github.com/confluentinc/cli/internal/pkg/output"
-	"github.com/confluentinc/cli/internal/pkg/resource"
 )
 
 func (c *command) newUpdateCommand() *cobra.Command {
@@ -21,6 +19,8 @@ func (c *command) newUpdateCommand() *cobra.Command {
 	}
 
 	cmd.Flags().String("name", "", "New name for Confluent Cloud environment.")
+	pcmd.AddContextFlag(cmd, c.CLICommand)
+	pcmd.AddOutputFlag(cmd)
 
 	cobra.CheckErr(cmd.MarkFlagRequired("name"))
 
@@ -28,19 +28,22 @@ func (c *command) newUpdateCommand() *cobra.Command {
 }
 
 func (c *command) update(cmd *cobra.Command, args []string) error {
-	id := args[0]
-
 	name, err := cmd.Flags().GetString("name")
 	if err != nil {
 		return err
 	}
 
-	updateEnvironment := orgv2.OrgV2Environment{DisplayName: orgv2.PtrString(name)}
-	_, httpResp, err := c.V2Client.UpdateOrgEnvironment(id, updateEnvironment)
+	environment := orgv2.OrgV2Environment{DisplayName: orgv2.PtrString(name)}
+	environment, err = c.V2Client.UpdateOrgEnvironment(args[0], environment)
 	if err != nil {
-		return errors.CatchOrgV2ResourceNotFoundError(err, resource.Environment, httpResp)
+		return err
 	}
 
-	output.ErrPrintf(errors.UpdateSuccessMsg, "name", "environment", id, name)
-	return nil
+	table := output.NewTable(cmd)
+	table.Add(&out{
+		IsCurrent: environment.GetId() == c.Context.GetCurrentEnvironment(),
+		Id:        environment.GetId(),
+		Name:      environment.GetDisplayName(),
+	})
+	return table.Print()
 }
