@@ -108,10 +108,7 @@ func (c *command) login(cmd *cobra.Command, _ []string) error {
 }
 
 func (c *command) loginCCloud(cmd *cobra.Command, url string) error {
-	orgResourceId, err := c.getOrgResourceId(cmd)
-	if err != nil {
-		return err
-	}
+	orgResourceId := c.getOrgResourceId(cmd)
 
 	noBrowser, err := cmd.Flags().GetBool("no-browser")
 	if err != nil {
@@ -173,7 +170,7 @@ func (c *command) loginCCloud(cmd *cobra.Command, url string) error {
 }
 
 func (c *command) printRemainingFreeCredit(client *ccloudv1.Client, currentOrg *ccloudv1.Organization) {
-	promoCodeClaims, err := client.Growth.GetFreeTrialInfo(context.Background(), currentOrg.Id)
+	promoCodeClaims, err := client.Growth.GetFreeTrialInfo(currentOrg.Id)
 	if err != nil {
 		log.CliLogger.Warnf("Failed to get free trial info: %v", err)
 		return
@@ -210,6 +207,7 @@ func (c *command) getCCloudCredentials(cmd *cobra.Command, url, orgResourceId st
 	if prompt {
 		return pauth.GetLoginCredentials(c.loginCredentialsManager.GetCloudCredentialsFromPrompt(orgResourceId))
 	}
+
 	filterParams := netrc.NetrcMachineParams{
 		IsCloud: true,
 		URL:     url,
@@ -221,7 +219,7 @@ func (c *command) getCCloudCredentials(cmd *cobra.Command, url, orgResourceId st
 
 	return pauth.GetLoginCredentials(
 		c.loginCredentialsManager.GetCloudCredentialsFromEnvVar(orgResourceId),
-		c.loginCredentialsManager.GetSsoCredentialsFromConfig(c.cfg),
+		c.loginCredentialsManager.GetSsoCredentialsFromConfig(c.cfg, url),
 		c.loginCredentialsManager.GetCredentialsFromKeychain(c.cfg, true, filterParams.Name, url),
 		c.loginCredentialsManager.GetCredentialsFromConfig(c.cfg, filterParams),
 		c.loginCredentialsManager.GetCredentialsFromNetrc(filterParams),
@@ -405,10 +403,9 @@ func validateURL(url string, isCCloud bool) (string, string, error) {
 	return url, strings.Join(msg, " and "), nil
 }
 
-func (c *command) getOrgResourceId(cmd *cobra.Command) (string, error) {
+func (c *command) getOrgResourceId(cmd *cobra.Command) string {
 	return pauth.GetLoginOrganization(
-		c.loginOrganizationManager.GetLoginOrganizationFromArgs(cmd),
-		c.loginOrganizationManager.GetLoginOrganizationFromEnvVar(cmd),
-		c.loginOrganizationManager.GetDefaultLoginOrganization(),
+		c.loginOrganizationManager.GetLoginOrganizationFromFlag(cmd),
+		c.loginOrganizationManager.GetLoginOrganizationFromEnvironmentVariable(),
 	)
 }
