@@ -22,7 +22,7 @@ type Context struct {
 	Environments           map[string]*EnvironmentContext    `json:"environments,omitempty"`
 	KafkaClusterContext    *KafkaClusterContext              `json:"kafka_cluster_context"`
 	SchemaRegistryClusters map[string]*SchemaRegistryCluster `json:"schema_registry_clusters"`
-	LastOrgId              string                            `json:"last_org_id"`
+	LastOrgId              string                            `json:"last_org_id,omitempty"`
 	FeatureFlags           *FeatureFlags                     `json:"feature_flags,omitempty"`
 
 	Platform   *Platform     `json:"-"`
@@ -40,7 +40,7 @@ func newContext(name string, platform *Platform, credential *Credential, kafkaCl
 		Credential:             credential,
 		CredentialName:         credential.Name,
 		CurrentEnvironment:     envId,
-		Environments:           map[string]*EnvironmentContext{envId: {}},
+		Environments:           map[string]*EnvironmentContext{},
 		SchemaRegistryClusters: schemaRegistryClusters,
 		State:                  state,
 		Config:                 config,
@@ -187,6 +187,13 @@ func (c *Context) GetUser() *ccloudv1.User {
 	return nil
 }
 
+func (c *Context) GetCurrentOrganization() string {
+	if c != nil {
+		return c.LastOrgId
+	}
+	return ""
+}
+
 func (c *Context) GetOrganization() *ccloudv1.Organization {
 	if auth := c.GetAuth(); auth != nil {
 		return auth.Organization
