@@ -2,15 +2,13 @@ package test
 
 func (s *CLITestSuite) TestEnvironment() {
 	tests := []CLITest{
-		// Only log in at the beginning so active env is not reset
-		// tt.workflow=true so login is not reset
 		{args: "environment list", fixture: "environment/1.golden", login: "cloud"},
 		{args: "environment use not-595", fixture: "environment/2.golden"},
 		{args: "environment update not-595 --name new-other-name", fixture: "environment/3.golden"},
 		{args: "environment list", fixture: "environment/4.golden"},
 		{args: "environment list -o json", fixture: "environment/5.golden"},
 		{args: "environment list -o yaml", fixture: "environment/6.golden"},
-		{args: "environment use non-existent-id", fixture: "environment/7.golden", exitCode: 1},
+		{args: "environment use env-dne", fixture: "environment/7.golden", exitCode: 1},
 		{args: "environment create saucayyy", fixture: "environment/8.golden"},
 		{args: "environment create saucayyy -o json", fixture: "environment/9.golden"},
 		{args: "environment create saucayyy -o yaml", fixture: "environment/10.golden"},
@@ -38,3 +36,8 @@ func (s *CLITestSuite) TestEnvironmentDescribe() {
 		s.runIntegrationTest(tt)
 	}
 }
+
+func (s *CLITestSuite) TestEnvironmentAutocomplete() {
+	test := CLITest{args: `__complete environment describe ""`, login: "cloud", fixture: "environment/describe-autocomplete.golden"}
+	s.runIntegrationTest(test)
+}
